//
//  NSString+RegEx.m
//  Trivie
//
//  Created by Jennifer Duffey on 3/16/12.
//  Copyright (c) 2012 Trivie. All rights reserved.
//

#import "NSString+RegEx.h"

@implementation NSString (RegEx)

-(NSString *) stringByReplacingRegexPattern:(NSString *)regex withString:(NSString *) replacement caseInsensitive:(BOOL)ignoreCase {
	return [self stringByReplacingRegexPattern:regex withString:replacement caseInsensitive:ignoreCase treatAsOneLine:NO];
}

-(NSString *) stringByReplacingRegexPattern:(NSString *)regex withString:(NSString *) replacement caseInsensitive:(BOOL) ignoreCase treatAsOneLine:(BOOL) assumeMultiLine {
	
	NSUInteger options=0;
	if (ignoreCase) {
		options = options | NSRegularExpressionCaseInsensitive;
	}
	if (assumeMultiLine) {
		options = options | NSRegularExpressionDotMatchesLineSeparators;
	}
	
	NSError *error=nil;
	NSRegularExpression *pattern = [NSRegularExpression regularExpressionWithPattern:regex options:options error:&error];
	if (error) {
		NSLog(@"Error creating Regex: %@",[error description]);
		return nil;
	}
	
	NSString *retVal= [pattern stringByReplacingMatchesInString:self options:0 range:NSMakeRange(0, [self length]) withTemplate:replacement];
	return retVal;
}

-(NSString *) stringByReplacingRegexPattern:(NSString *)regex withString:(NSString *) replacement {
	return [self stringByReplacingRegexPattern:regex withString:replacement caseInsensitive:NO treatAsOneLine:NO];
}

-(NSArray *) stringsByExtractingGroupsUsingRegexPattern:(NSString *)regex caseInsensitive:(BOOL) ignoreCase treatAsOneLine:(BOOL) assumeMultiLine {
	NSUInteger options=0;
	if (ignoreCase) {
		options = options | NSRegularExpressionCaseInsensitive;
	}
	if (assumeMultiLine) {
		options = options | NSRegularExpressionDotMatchesLineSeparators;
	}
	
	NSError *error=nil;
	NSRegularExpression *pattern = [NSRegularExpression regularExpressionWithPattern:regex options:options error:&error];
	if (error) {
		NSLog(@"Error creating Regex: %@",[error description]);
		return nil;
	}
	
	__unsafe_unretained NSMutableArray *retVal = [NSMutableArray array];
	[pattern enumerateMatchesInString:self options:0 range:NSMakeRange(0, [self length]) usingBlock:^(NSTextCheckingResult *result, NSMatchingFlags flags, BOOL *stop) {
		//Note, we only want to return the things in parens, so we're skipping index 0 intentionally
		for (NSUInteger i = 1; i < [result numberOfRanges]; i++) {
			NSString *matchedString=[self substringWithRange:[result rangeAtIndex:i]];
			[retVal addObject:matchedString];
		}
	}];
	return retVal;
}

-(NSArray *) stringsByExtractingGroupsUsingRegexPattern:(NSString *)regex {
	return [self stringsByExtractingGroupsUsingRegexPattern:regex caseInsensitive:NO treatAsOneLine:NO];
}

-(BOOL) matchesPatternRegexPattern:(NSString *)regex caseInsensitive:(BOOL) ignoreCase treatAsOneLine:(BOOL) assumeMultiLine {
	NSUInteger options=0;
	if (ignoreCase) {
		options = options | NSRegularExpressionCaseInsensitive;
	}
	if (assumeMultiLine) {
		options = options | NSRegularExpressionDotMatchesLineSeparators;
	}
	
	NSError *error=nil;
	NSRegularExpression *pattern = [NSRegularExpression regularExpressionWithPattern:regex options:options error:&error];
	if (error) {
		NSLog(@"Error creating Regex: %@",[error description]);
		return NO;  //Can't possibly match an invalid Regex
	}
	
	return ([pattern numberOfMatchesInString:self options:0 range:NSMakeRange(0, [self length])] > 0);
}

-(BOOL) matchesPatternRegexPattern:(NSString *)regex 
{
	return [self matchesPatternRegexPattern:regex caseInsensitive:NO treatAsOneLine:NO];
}

@end
